@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -60,6 +62,13 @@ class CreateSecretRequest(AbstractModel):
                 obj = Tag()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateSecretResponse(AbstractModel):
@@ -116,6 +125,13 @@ class DeleteSecretRequest(AbstractModel):
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
         self.RecoveryWindowInDays = params.get("RecoveryWindowInDays")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteSecretResponse(AbstractModel):
@@ -162,6 +178,13 @@ class DeleteSecretVersionRequest(AbstractModel):
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
         self.VersionId = params.get("VersionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteSecretVersionResponse(AbstractModel):
@@ -204,6 +227,13 @@ class DescribeSecretRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSecretResponse(AbstractModel):
@@ -266,6 +296,13 @@ class DisableSecretRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableSecretResponse(AbstractModel):
@@ -304,6 +341,13 @@ class EnableSecretRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableSecretResponse(AbstractModel):
@@ -373,6 +417,13 @@ class GetSecretValueRequest(AbstractModel):
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
         self.VersionId = params.get("VersionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetSecretValueResponse(AbstractModel):
@@ -454,6 +505,13 @@ class ListSecretVersionIdsRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListSecretVersionIdsResponse(AbstractModel):
@@ -527,6 +585,13 @@ class ListSecretsRequest(AbstractModel):
                 obj = TagFilter()
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListSecretsResponse(AbstractModel):
@@ -586,6 +651,13 @@ class PutSecretValueRequest(AbstractModel):
         self.VersionId = params.get("VersionId")
         self.SecretBinary = params.get("SecretBinary")
         self.SecretString = params.get("SecretString")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PutSecretValueResponse(AbstractModel):
@@ -628,6 +700,13 @@ class RestoreSecretRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RestoreSecretResponse(AbstractModel):
@@ -694,6 +773,13 @@ class SecretMetadata(AbstractModel):
         self.DeleteTime = params.get("DeleteTime")
         self.CreateTime = params.get("CreateTime")
         self.KmsKeyType = params.get("KmsKeyType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Tag(AbstractModel):
@@ -715,6 +801,13 @@ class Tag(AbstractModel):
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
         self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TagFilter(AbstractModel):
@@ -736,6 +829,13 @@ class TagFilter(AbstractModel):
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
         self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateDescriptionRequest(AbstractModel):
@@ -757,6 +857,13 @@ class UpdateDescriptionRequest(AbstractModel):
     def _deserialize(self, params):
         self.SecretName = params.get("SecretName")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateDescriptionResponse(AbstractModel):
@@ -807,6 +914,13 @@ class UpdateSecretRequest(AbstractModel):
         self.VersionId = params.get("VersionId")
         self.SecretBinary = params.get("SecretBinary")
         self.SecretString = params.get("SecretString")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateSecretResponse(AbstractModel):
@@ -852,4 +966,11 @@ class VersionInfo(AbstractModel):
 
     def _deserialize(self, params):
         self.VersionId = params.get("VersionId")
-        self.CreateTime = params.get("CreateTime")
\ No newline at end of file
+        self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
